@@ -5,10 +5,11 @@ use time::Date;
 use crate::{
     blocking::runtime::BlockingRuntime,
     quote::{
-        AdjustType, Candlestick, IntradayLine, IssuerInfo, MarketTradingDays, MarketTradingSession,
-        OptionQuote, ParticipantInfo, Period, PushEvent, RealtimeQuote, SecurityBrokers,
-        SecurityDepth, SecurityQuote, SecurityStaticInfo, StrikePriceInfo, SubFlags, Subscription,
-        Trade, WarrantQuote,
+        AdjustType, Candlestick, CapitalDistributionResponse, CapitalFlowLine, IntradayLine,
+        IssuerInfo, MarketTradingDays, MarketTradingSession, OptionQuote, ParticipantInfo, Period,
+        PushEvent, RealtimeQuote, SecurityBrokers, SecurityDepth, SecurityQuote,
+        SecurityStaticInfo, StrikePriceInfo, SubFlags, Subscription, Trade, WarrantQuote,
+        WatchListGroup,
     },
     Config, Market, QuoteContext, Result,
 };
@@ -96,6 +97,49 @@ impl QuoteContextSync {
             .call(move |ctx| async move { ctx.unsubscribe(symbols, sub_types.into()).await })
     }
 
+    /// Subscribe security candlesticks
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use std::{sync::Arc, thread::sleep, time::Duration};
+    ///
+    /// use longbridge::{
+    ///     blocking::QuoteContextSync,
+    ///     quote::{Period, PushEvent},
+    ///     Config,
+    /// };
+    ///
+    /// fn event_handler(event: PushEvent) {
+    ///     println!("{:?}", event);
+    /// }
+    ///
+    /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
+    /// let config = Arc::new(Config::from_env()?);
+    /// let ctx = QuoteContextSync::try_new(config, event_handler)?;
+    ///
+    /// ctx.subscribe_candlesticks("AAPL.US", Period::OneMinute)?;
+    /// sleep(Duration::from_secs(30));
+    /// # Ok(())
+    /// # }
+    /// ```
+    pub fn subscribe_candlesticks<T>(&self, symbol: T, period: Period) -> Result<()>
+    where
+        T: Into<String> + Send + 'static,
+    {
+        self.rt
+            .call(move |ctx| async move { ctx.subscribe_candlesticks(symbol, period).await })
+    }
+
+    /// Unsubscribe security candlesticks
+    pub fn unsubscribe_candlesticks<T>(&self, symbol: T, period: Period) -> Result<()>
+    where
+        T: Into<String> + Send + 'static,
+    {
+        self.rt
+            .call(move |ctx| async move { ctx.unsubscribe_candlesticks(symbol, period).await })
+    }
+
     /// Get subscription information
     ///
     /// # Examples
@@ -521,6 +565,83 @@ impl QuoteContextSync {
             .call(move |ctx| async move { ctx.trading_days(market, begin, end).await })
     }
 
+    /// Get capital flow intraday
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use std::sync::Arc;
+    ///
+    /// use longbridge::{blocking::QuoteContextSync, Config};
+    /// use time::macros::date;
+    ///
+    /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
+    /// let config = Arc::new(Config::from_env()?);
+    /// let ctx = QuoteContextSync::try_new(config, |_| ())?;
+    ///
+    /// let resp = ctx.capital_flow("700.HK")?;
+    /// println!("{:?}", resp);
+    /// # Ok(())
+    /// # }
+    /// ```
+    pub fn capital_flow(
+        &self,
+        symbol: impl Into<String> + Send + 'static,
+    ) -> Result<Vec<CapitalFlowLine>> {
+        self.rt
+            .call(move |ctx| async move { ctx.capital_flow(symbol).await })
+    }
+
+    /// Get capital distribution
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use std::sync::Arc;
+    ///
+    /// use longbridge::{blocking::QuoteContextSync, Config};
+    /// use time::macros::date;
+    ///
+    /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
+    /// let config = Arc::new(Config::from_env()?);
+    /// let ctx = QuoteContextSync::try_new(config, |_| ())?;
+    ///
+    /// let resp = ctx.capital_distribution("700.HK")?;
+    /// println!("{:?}", resp);
+    /// # Ok(())
+    /// # }
+    /// ```
+    pub fn capital_distribution(
+        &self,
+        symbol: impl Into<String> + Send + 'static,
+    ) -> Result<CapitalDistributionResponse> {
+        self.rt
+            .call(move |ctx| async move { ctx.capital_distribution(symbol).await })
+    }
+
+    /// Get watch list
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use std::sync::Arc;
+    ///
+    /// use longbridge::{blocking::QuoteContextSync, Config};
+    ///
+    /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
+    /// let config = Arc::new(Config::from_env()?);
+    /// let ctx = QuoteContextSync::try_new(config, |_| ())?;
+    ///
+    /// let resp = ctx.watch_list()?;
+    /// println!("{:?}", resp);
+    /// # Ok(())
+    /// # }
+    /// ```
+    pub fn watch_list(&self) -> Result<Vec<WatchListGroup>> {
+        self.rt
+            .call(move |ctx| async move { ctx.watch_list().await })
+    }
+
     /// Get real-time quotes
     ///
     /// Get real-time quotes of the subscribed symbols, it always returns the
@@ -651,4 +772,38 @@ impl QuoteContextSync {
         self.rt
             .call(move |ctx| async move { ctx.realtime_brokers(symbol).await })
     }
+
+    /// Get real-time candlesticks
+    ///
+    /// Get real-time candlesticks of the subscribed symbols, it always returns
+    /// the data in the local storage.
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use std::{sync::Arc, thread::sleep, time::Duration};
+    ///
+    /// use longbridge::{blocking::QuoteContextSync, quote::Period, Config, Market};
+    ///
+    /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
+    /// let config = Arc::new(Config::from_env()?);
+    /// let ctx = QuoteContextSync::try_new(config, |_| ())?;
+    ///
+    /// ctx.subscribe_candlesticks("AAPL.US", Period::OneMinute)?;
+    /// sleep(Duration::from_secs(5));
+    ///
+    /// let resp = ctx.realtime_candlesticks("AAPL.US", Period::OneMinute, 10)?;
+    /// println!("{:?}", resp);
+    /// # Ok(())
+    /// # }
+    /// ```
+    pub fn realtime_candlesticks(
+        &self,
+        symbol: impl Into<String> + Send + 'static,
+        period: Period,
+        count: usize,
+    ) -> Result<Vec<Candlestick>> {
+        self.rt
+            .call(move |ctx| async move { ctx.realtime_candlesticks(symbol, period, count).await })
+    }
 }
