@@ -9,6 +9,7 @@ mod macros;
 
 mod config;
 mod error;
+mod serde_utils;
 mod types;
 
 #[cfg(feature = "blocking")]
@@ -17,8 +18,8 @@ pub mod blocking;
 pub mod quote;
 pub mod trade;
 
-pub use config::Config;
-pub use error::{Error, Result};
+pub use config::{Config, Language};
+pub use error::{Error, Result, SimpleError};
 pub use quote::QuoteContext;
 pub use rust_decimal::Decimal;
 pub use trade::TradeContext;
