@@ -1,7 +1,9 @@
 use std::{sync::Arc, time::Duration};
 
+use longbridge_httpcli::{HttpClient, Method};
 use longbridge_proto::quote;
 use longbridge_wscli::WsClientError;
+use serde::Deserialize;
 use time::Date;
 use tokio::sync::{mpsc, oneshot};
 
@@ -12,10 +14,10 @@ use crate::{
         core::{Command, Core},
         sub_flags::SubFlags,
         utils::{format_date, parse_date},
-        AdjustType, Candlestick, IntradayLine, IssuerInfo, MarketTradingDays, MarketTradingSession,
-        OptionQuote, ParticipantInfo, Period, PushEvent, RealtimeQuote, SecurityBrokers,
-        SecurityDepth, SecurityQuote, SecurityStaticInfo, StrikePriceInfo, Subscription, Trade,
-        WarrantQuote,
+        AdjustType, Candlestick, CapitalDistributionResponse, CapitalFlowLine, IntradayLine,
+        IssuerInfo, MarketTradingDays, MarketTradingSession, OptionQuote, ParticipantInfo, Period,
+        PushEvent, RealtimeQuote, SecurityBrokers, SecurityDepth, SecurityQuote,
+        SecurityStaticInfo, StrikePriceInfo, Subscription, Trade, WarrantQuote, WatchListGroup,
     },
     Config, Error, Market, Result,
 };
@@ -29,6 +31,7 @@ const TRADING_SESSION_CACHE_TIMEOUT: Duration = Duration::from_secs(60 * 60 * 2)
 /// Quote context
 #[derive(Clone)]
 pub struct QuoteContext {
+    http_cli: HttpClient,
     command_tx: mpsc::UnboundedSender<Command>,
     cache_participants: Cache<Vec<ParticipantInfo>>,
     cache_issuers: Cache<Vec<IssuerInfo>>,
@@ -42,11 +45,13 @@ impl QuoteContext {
     pub async fn try_new(
         config: Arc<Config>,
     ) -> Result<(Self, mpsc::UnboundedReceiver<PushEvent>)> {
+        let http_cli = config.create_http_client();
         let (command_tx, command_rx) = mpsc::unbounded_channel();
         let (push_tx, push_rx) = mpsc::unbounded_channel();
         tokio::spawn(Core::try_new(config, command_rx, push_tx).await?.run());
         Ok((
             QuoteContext {
+                http_cli,
                 command_tx,
                 cache_participants: Cache::new(PARTICIPANT_INFO_CACHE_TIMEOUT),
                 cache_issuers: Cache::new(ISSUER_INFO_CACHE_TIMEOUT),
@@ -182,6 +187,61 @@ impl QuoteContext {
         reply_rx.await.map_err(|_| WsClientError::ClientClosed)?
     }
 
+    /// Subscribe security candlesticks
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use std::sync::Arc;
+    ///
+    /// use longbridge::{
+    ///     quote::{Period, QuoteContext},
+    ///     Config,
+    /// };
+    ///
+    /// # tokio::runtime::Runtime::new().unwrap().block_on(async {
+    /// let config = Arc::new(Config::from_env()?);
+    /// let (ctx, mut receiver) = QuoteContext::try_new(config).await?;
+    ///
+    /// ctx.subscribe_candlesticks("AAPL.US", Period::OneMinute)
+    ///     .await?;
+    /// while let Some(msg) = receiver.recv().await {
+    ///     println!("{:?}", msg);
+    /// }
+    /// # Ok::<_, Box<dyn std::error::Error>>(())
+    /// # });
+    /// ```
+    pub async fn subscribe_candlesticks<T>(&self, symbol: T, period: Period) -> Result<()>
+    where
+        T: Into<String>,
+    {
+        let (reply_tx, reply_rx) = oneshot::channel();
+        self.command_tx
+            .send(Command::SubscribeCandlesticks {
+                symbol: symbol.into(),
+                period,
+                reply_tx,
+            })
+            .map_err(|_| WsClientError::ClientClosed)?;
+        reply_rx.await.map_err(|_| WsClientError::ClientClosed)?
+    }
+
+    /// Unsubscribe security candlesticks
+    pub async fn unsubscribe_candlesticks<T>(&self, symbol: T, period: Period) -> Result<()>
+    where
+        T: Into<String>,
+    {
+        let (reply_tx, reply_rx) = oneshot::channel();
+        self.command_tx
+            .send(Command::UnsubscribeCandlesticks {
+                symbol: symbol.into(),
+                period,
+                reply_tx,
+            })
+            .map_err(|_| WsClientError::ClientClosed)?;
+        reply_rx.await.map_err(|_| WsClientError::ClientClosed)?
+    }
+
     /// Get subscription information
     ///
     /// # Examples
@@ -829,6 +889,107 @@ impl QuoteContext {
         })
     }
 
+    /// Get capital flow intraday
+    ///
+    /// Reference: <https://open.longbridgeapp.com/en/docs/quote/pull/capital-flow-intraday>
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use std::sync::Arc;
+    ///
+    /// use longbridge::{quote::QuoteContext, Config};
+    ///
+    /// # tokio::runtime::Runtime::new().unwrap().block_on(async {
+    /// let config = Arc::new(Config::from_env()?);
+    /// let (ctx, _) = QuoteContext::try_new(config).await?;
+    ///
+    /// let resp = ctx.capital_flow("700.HK").await?;
+    /// println!("{:?}", resp);
+    /// # Ok::<_, Box<dyn std::error::Error>>(())
+    /// # });
+    pub async fn capital_flow(&self, symbol: impl Into<String>) -> Result<Vec<CapitalFlowLine>> {
+        self.request::<_, quote::CapitalFlowIntradayResponse>(
+            cmd_code::GET_CAPITAL_FLOW_INTRADAY,
+            quote::CapitalFlowIntradayRequest {
+                symbol: symbol.into(),
+            },
+        )
+        .await?
+        .capital_flow_lines
+        .into_iter()
+        .map(TryInto::try_into)
+        .collect()
+    }
+
+    /// Get capital distribution
+    ///
+    /// Reference: <https://open.longbridgeapp.com/en/docs/quote/pull/capital-distribution>
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use std::sync::Arc;
+    ///
+    /// use longbridge::{quote::QuoteContext, Config};
+    ///
+    /// # tokio::runtime::Runtime::new().unwrap().block_on(async {
+    /// let config = Arc::new(Config::from_env()?);
+    /// let (ctx, _) = QuoteContext::try_new(config).await?;
+    ///
+    /// let resp = ctx.capital_distribution("700.HK").await?;
+    /// println!("{:?}", resp);
+    /// # Ok::<_, Box<dyn std::error::Error>>(())
+    /// # });
+    pub async fn capital_distribution(
+        &self,
+        symbol: impl Into<String>,
+    ) -> Result<CapitalDistributionResponse> {
+        self.request::<_, quote::CapitalDistributionResponse>(
+            cmd_code::GET_SECURITY_CAPITAL_DISTRIBUTION,
+            quote::SecurityRequest {
+                symbol: symbol.into(),
+            },
+        )
+        .await?
+        .try_into()
+    }
+
+    /// Get watch list
+    ///
+    /// Reference: <https://open.longbridgeapp.com/en/docs/quote/individual/watchlist_groups>
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use std::sync::Arc;
+    ///
+    /// use longbridge::{quote::QuoteContext, Config};
+    ///
+    /// # tokio::runtime::Runtime::new().unwrap().block_on(async {
+    /// let config = Arc::new(Config::from_env()?);
+    /// let (ctx, _) = QuoteContext::try_new(config).await?;
+    ///
+    /// let resp = ctx.watch_list().await?;
+    /// println!("{:?}", resp);
+    /// # Ok::<_, Box<dyn std::error::Error>>(())
+    /// # });
+    /// ```
+    pub async fn watch_list(&self) -> Result<Vec<WatchListGroup>> {
+        #[derive(Debug, Deserialize)]
+        struct Response {
+            groups: Vec<WatchListGroup>,
+        }
+
+        let resp = self
+            .http_cli
+            .request(Method::GET, "/v1/watchlist/groups")
+            .response::<Response>()
+            .send()
+            .await?;
+        Ok(resp.groups)
+    }
+
     /// Get real-time quotes
     ///
     /// Get real-time quotes of the subscribed symbols, it always returns the
@@ -994,4 +1155,52 @@ impl QuoteContext {
             .map_err(|_| WsClientError::ClientClosed)?;
         Ok(reply_rx.await.map_err(|_| WsClientError::ClientClosed)?)
     }
+
+    /// Get real-time candlesticks
+    ///
+    /// Get real-time candlesticks of the subscribed symbols, it always returns
+    /// the data in the local storage.
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use std::{sync::Arc, time::Duration};
+    ///
+    /// use longbridge::{
+    ///     quote::{Period, QuoteContext},
+    ///     Config,
+    /// };
+    ///
+    /// # tokio::runtime::Runtime::new().unwrap().block_on(async {
+    /// let config = Arc::new(Config::from_env()?);
+    /// let (ctx, _) = QuoteContext::try_new(config).await?;
+    ///
+    /// ctx.subscribe_candlesticks("AAPL.US", Period::OneMinute)
+    ///     .await?;
+    /// tokio::time::sleep(Duration::from_secs(5)).await;
+    ///
+    /// let resp = ctx
+    ///     .realtime_candlesticks("AAPL.US", Period::OneMinute, 10)
+    ///     .await?;
+    /// println!("{:?}", resp);
+    /// # Ok::<_, Box<dyn std::error::Error>>(())
+    /// # });
+    /// ```
+    pub async fn realtime_candlesticks(
+        &self,
+        symbol: impl Into<String>,
+        period: Period,
+        count: usize,
+    ) -> Result<Vec<Candlestick>> {
+        let (reply_tx, reply_rx) = oneshot::channel();
+        self.command_tx
+            .send(Command::GetRealtimeCandlesticks {
+                symbol: symbol.into(),
+                period,
+                count,
+                reply_tx,
+            })
+            .map_err(|_| WsClientError::ClientClosed)?;
+        Ok(reply_rx.await.map_err(|_| WsClientError::ClientClosed)?)
+    }
 }
