@@ -1,12 +1,13 @@
-use longbridge_proto::quote::{self, TradeSession, TradeStatus};
-use num_enum::{FromPrimitive, IntoPrimitive, TryFromPrimitive};
+use longbridge_proto::quote::{self, Period, TradeSession, TradeStatus};
+use num_enum::{FromPrimitive, IntoPrimitive};
 use rust_decimal::Decimal;
-use strum_macros::EnumString;
+use serde::Deserialize;
+use strum_macros::{Display, EnumString};
 use time::{Date, OffsetDateTime, Time};
 
 use crate::{
     quote::{utils::parse_date, SubFlags},
-    Error, Market, Result,
+    serde_utils, Error, Market, Result,
 };
 
 /// Subscription
@@ -16,6 +17,8 @@ pub struct Subscription {
     pub symbol: String,
     /// Subscription flags
     pub sub_types: SubFlags,
+    /// Candlesticks
+    pub candlesticks: Vec<Period>,
 }
 
 /// Depth
@@ -139,14 +142,72 @@ impl TryFrom<quote::Trade> for Trade {
     }
 }
 
-/// Derivative type
-#[derive(Debug, TryFromPrimitive)]
-#[repr(i32)]
-pub enum DerivativeType {
-    /// US stock options
-    Option = 1,
-    /// HK warrants
-    Warrant = 2,
+bitflags::bitflags! {
+    /// Derivative type
+    pub struct DerivativeType: u8 {
+        /// US stock options
+        const OPTION = 0x1;
+
+        /// HK warrants
+        const WARRANT = 0x2;
+    }
+}
+
+/// Security board
+#[derive(Debug, Copy, Clone, Hash, Eq, PartialEq, EnumString, Display)]
+#[allow(clippy::upper_case_acronyms)]
+pub enum SecurityBoard {
+    /// Unknown
+    #[strum(disabled)]
+    Unknown,
+    /// US Main Board
+    USMain,
+    /// US Pink Board
+    USPink,
+    /// Dow Jones Industrial Average
+    USDJI,
+    /// Nasdsaq Index
+    USNSDQ,
+    /// US Industry Board
+    USSector,
+    /// US Option
+    USOption,
+    /// US Sepecial Option
+    USOptionS,
+    /// Hong Kong Equity Securities
+    HKEquity,
+    /// HK PreIPO Security
+    HKPreIPO,
+    /// HK Warrant
+    HKWarrant,
+    /// Hang Seng Index
+    HKHS,
+    /// HK Industry Board
+    HKSector,
+    /// SH Main Board(Connect)
+    SHMainConnect,
+    /// SH Main Board(Non Connect)
+    SHMainNonConnect,
+    /// SH Science and Technology Innovation Board
+    SHSTAR,
+    /// CN Index
+    CNIX,
+    /// CN Industry Board
+    CNSector,
+    /// SZ Main Board(Connect)
+    SZMainConnect,
+    /// SZ Main Board(Non Connect)
+    SZMainNonConnect,
+    /// SZ Gem Board(Connect)
+    SZGEMConnect,
+    /// SZ Gem Board(Non Connect)
+    SZGEMNonConnect,
+    /// SG Main Board
+    SGMain,
+    /// Singapore Straits Index
+    STI,
+    /// SG Industry Board
+    SGSector,
 }
 
 /// The basic information of securities
@@ -181,7 +242,9 @@ pub struct SecurityStaticInfo {
     /// Dividend yield
     pub dividend_yield: Decimal,
     /// Types of supported derivatives
-    pub stock_derivatives: Vec<DerivativeType>,
+    pub stock_derivatives: DerivativeType,
+    /// Board
+    pub board: SecurityBoard,
 }
 
 impl TryFrom<quote::StaticInfo> for SecurityStaticInfo {
@@ -203,11 +266,15 @@ impl TryFrom<quote::StaticInfo> for SecurityStaticInfo {
             eps_ttm: resp.eps_ttm.parse().unwrap_or_default(),
             bps: resp.bps.parse().unwrap_or_default(),
             dividend_yield: resp.dividend_yield.parse().unwrap_or_default(),
-            stock_derivatives: resp
-                .stock_derivatives
-                .into_iter()
-                .filter_map(|x| x.try_into().ok())
-                .collect(),
+            stock_derivatives: resp.stock_derivatives.into_iter().fold(
+                DerivativeType::empty(),
+                |acc, value| match value {
+                    1 => acc | DerivativeType::OPTION,
+                    2 => acc | DerivativeType::WARRANT,
+                    _ => acc,
+                },
+            ),
+            board: resp.board.parse().unwrap_or(SecurityBoard::Unknown),
         })
     }
 }
@@ -485,7 +552,7 @@ pub struct WarrantQuote {
     /// Outstanding ratio
     pub outstanding_ratio: Decimal,
     /// Outstanding quantity
-    pub outstanding_qty: i64,
+    pub outstanding_quantity: i64,
     /// Conversion ratio
     pub conversion_ratio: Decimal,
     /// Warrant type
@@ -529,7 +596,7 @@ impl TryFrom<quote::WarrantQuote> for WarrantQuote {
             last_trade_date: parse_date(&warrant_extend.last_trade_date)
                 .map_err(|err| Error::parse_field_error("last_trade_date", err))?,
             outstanding_ratio: warrant_extend.outstanding_ratio.parse().unwrap_or_default(),
-            outstanding_qty: warrant_extend.outstanding_qty,
+            outstanding_quantity: warrant_extend.outstanding_qty,
             conversion_ratio: warrant_extend.conversion_ratio.parse().unwrap_or_default(),
             category: warrant_extend.category.parse().unwrap_or_default(),
             strike_price: warrant_extend.strike_price.parse().unwrap_or_default(),
@@ -620,7 +687,7 @@ impl TryFrom<quote::Line> for IntradayLine {
 }
 
 /// Candlestick
-#[derive(Debug, Clone)]
+#[derive(Debug, Copy, Clone)]
 pub struct Candlestick {
     /// Close price
     pub close: Decimal,
@@ -655,6 +722,36 @@ impl TryFrom<quote::Candlestick> for Candlestick {
     }
 }
 
+impl From<longbridge_candlesticks::Candlestick> for Candlestick {
+    #[inline]
+    fn from(candlestick: longbridge_candlesticks::Candlestick) -> Self {
+        Self {
+            close: candlestick.close,
+            open: candlestick.open,
+            low: candlestick.low,
+            high: candlestick.high,
+            volume: candlestick.volume,
+            turnover: candlestick.turnover,
+            timestamp: candlestick.time,
+        }
+    }
+}
+
+impl From<Candlestick> for longbridge_candlesticks::Candlestick {
+    #[inline]
+    fn from(candlestick: Candlestick) -> Self {
+        Self {
+            time: candlestick.timestamp,
+            open: candlestick.open,
+            high: candlestick.high,
+            low: candlestick.low,
+            close: candlestick.close,
+            volume: candlestick.volume,
+            turnover: candlestick.turnover,
+        }
+    }
+}
+
 /// Strike price info
 #[derive(Debug, Clone)]
 pub struct StrikePriceInfo {
@@ -791,7 +888,7 @@ pub struct MarketTradingSession {
     /// Market
     pub market: Market,
     /// Trading session
-    pub trade_session: Vec<TradingSessionInfo>,
+    pub trade_sessions: Vec<TradingSessionInfo>,
 }
 
 impl TryFrom<quote::MarketTradePeriod> for MarketTradingSession {
@@ -800,7 +897,7 @@ impl TryFrom<quote::MarketTradePeriod> for MarketTradingSession {
     fn try_from(value: quote::MarketTradePeriod) -> Result<Self> {
         Ok(Self {
             market: value.market.parse().unwrap_or_default(),
-            trade_session: value
+            trade_sessions: value
                 .trade_session
                 .into_iter()
                 .map(TryInto::try_into)
@@ -818,4 +915,109 @@ pub struct MarketTradingDays {
     pub half_trading_days: Vec<Date>,
 }
 
-impl_default_for_enum_string!(OptionType, OptionDirection, WarrantType);
+/// Capital flow line
+#[derive(Debug, Clone)]
+pub struct CapitalFlowLine {
+    /// Inflow capital data
+    pub inflow: Decimal,
+    /// Time
+    pub timestamp: OffsetDateTime,
+}
+
+impl TryFrom<quote::capital_flow_intraday_response::CapitalFlowLine> for CapitalFlowLine {
+    type Error = Error;
+
+    fn try_from(value: quote::capital_flow_intraday_response::CapitalFlowLine) -> Result<Self> {
+        Ok(Self {
+            inflow: value.inflow.parse().unwrap_or_default(),
+            timestamp: OffsetDateTime::from_unix_timestamp(value.timestamp)
+                .map_err(|err| Error::parse_field_error("timestamp", err))?,
+        })
+    }
+}
+
+/// Capital distribution
+#[derive(Debug, Clone, Default)]
+pub struct CapitalDistribution {
+    /// Large order
+    pub large: Decimal,
+    /// Medium order
+    pub medium: Decimal,
+    /// Small order
+    pub small: Decimal,
+}
+
+impl TryFrom<quote::capital_distribution_response::CapitalDistribution> for CapitalDistribution {
+    type Error = Error;
+
+    fn try_from(value: quote::capital_distribution_response::CapitalDistribution) -> Result<Self> {
+        Ok(Self {
+            large: value.large.parse().unwrap_or_default(),
+            medium: value.medium.parse().unwrap_or_default(),
+            small: value.small.parse().unwrap_or_default(),
+        })
+    }
+}
+
+/// Capital distribution response
+#[derive(Debug, Clone)]
+pub struct CapitalDistributionResponse {
+    /// Time
+    pub timestamp: OffsetDateTime,
+    /// Inflow capital data
+    pub capital_in: CapitalDistribution,
+    /// Outflow capital data
+    pub capital_out: CapitalDistribution,
+}
+
+impl TryFrom<quote::CapitalDistributionResponse> for CapitalDistributionResponse {
+    type Error = Error;
+
+    fn try_from(value: quote::CapitalDistributionResponse) -> Result<Self> {
+        Ok(Self {
+            timestamp: OffsetDateTime::from_unix_timestamp(value.timestamp)
+                .map_err(|err| Error::parse_field_error("timestamp", err))?,
+            capital_in: value
+                .capital_in
+                .map(TryInto::try_into)
+                .transpose()?
+                .unwrap_or_default(),
+            capital_out: value
+                .capital_out
+                .map(TryInto::try_into)
+                .transpose()?
+                .unwrap_or_default(),
+        })
+    }
+}
+
+/// Watch list security
+#[derive(Debug, Clone, Deserialize)]
+pub struct WatchListSecurity {
+    /// Security symbol
+    pub symbol: String,
+    /// Market
+    pub market: Market,
+    /// Security name
+    pub name: String,
+    /// Watched price
+    #[serde(with = "serde_utils::decimal_opt_empty_is_none")]
+    pub watched_price: Option<Decimal>,
+    /// Watched time
+    #[serde(with = "serde_utils::timestamp")]
+    pub watched_at: OffsetDateTime,
+}
+
+/// Watch list group
+#[derive(Debug, Clone, Deserialize)]
+pub struct WatchListGroup {
+    /// Group id
+    #[serde(with = "serde_utils::int64_str")]
+    pub id: i64,
+    /// Group name
+    pub name: String,
+    /// Securities
+    pub securities: Vec<WatchListSecurity>,
+}
+
+impl_default_for_enum_string!(OptionType, OptionDirection, WarrantType, SecurityBoard);
