@@ -10,13 +10,17 @@ use crate::{
         core::{Command, Core},
         AccountBalance, CashFlow, Execution, FundPositionsResponse, GetCashFlowOptions,
         GetFundPositionsOptions, GetHistoryExecutionsOptions, GetHistoryOrdersOptions,
-        GetStockPositionsOptions, GetTodayExecutionsOptions, GetTodayOrdersOptions, Order,
-        PushEvent, ReplaceOrderOptions, StockPositionsResponse, SubmitOrderOptions, TopicType,
+        GetStockPositionsOptions, GetTodayExecutionsOptions, GetTodayOrdersOptions, MarginRatio,
+        Order, PushEvent, ReplaceOrderOptions, StockPositionsResponse, SubmitOrderOptions,
+        TopicType,
     },
     Config, Result,
 };
 
-/// Response for withdraw order request
+#[derive(Debug, Deserialize)]
+struct EmptyResponse {}
+
+/// Response for submit order request
 #[derive(Debug, Deserialize)]
 pub struct SubmitOrderResponse {
     /// Order id
@@ -51,6 +55,40 @@ impl TradeContext {
     /// Subscribe
     ///
     /// Reference: <https://open.longbridgeapp.com/en/docs/trade/trade-push#subscribe>
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use std::sync::Arc;
+    ///
+    /// use longbridge::{
+    ///     decimal,
+    ///     trade::{OrderSide, OrderType, SubmitOrderOptions, TimeInForceType, TradeContext},
+    ///     Config,
+    /// };
+    ///
+    /// # tokio::runtime::Runtime::new().unwrap().block_on(async {
+    /// let config = Arc::new(Config::from_env()?);
+    /// let (ctx, mut receiver) = TradeContext::try_new(config).await?;
+    ///
+    /// let opts = SubmitOrderOptions::new(
+    ///     "700.HK",
+    ///     OrderType::LO,
+    ///     OrderSide::Buy,
+    ///     200,
+    ///     TimeInForceType::Day,
+    /// )
+    /// .submitted_price(decimal!(50i32));
+    /// let resp = ctx.submit_order(opts).await?;
+    /// println!("{:?}", resp);
+    ///
+    /// while let Some(event) = receiver.recv().await {
+    ///     println!("{:?}", event);
+    /// }
+    ///
+    /// # Ok::<_, Box<dyn std::error::Error>>(())
+    /// # });
+    /// ```
     pub async fn subscribe<I>(&self, topics: I) -> Result<()>
     where
         I: IntoIterator<Item = TopicType>,
@@ -288,8 +326,7 @@ impl TradeContext {
     /// let config = Arc::new(Config::from_env()?);
     /// let (ctx, _) = TradeContext::try_new(config).await?;
     ///
-    /// let opts =
-    ///     ReplaceOrderOptions::new("709043056541253632", decimal!(100i32)).price(decimal!(300i32));
+    /// let opts = ReplaceOrderOptions::new("709043056541253632", 100).price(decimal!(300i32));
     /// let resp = ctx.replace_order(opts).await?;
     /// println!("{:?}", resp);
     /// # Ok::<_, Box<dyn std::error::Error>>(())
@@ -300,8 +337,10 @@ impl TradeContext {
             .http_cli
             .request(Method::PUT, "/v1/trade/order")
             .body(options)
+            .response::<EmptyResponse>()
             .send()
-            .await?)
+            .await
+            .map(|_| ())?)
     }
 
     /// Submit order
@@ -327,7 +366,7 @@ impl TradeContext {
     ///     "700.HK",
     ///     OrderType::LO,
     ///     OrderSide::Buy,
-    ///     decimal!(200i32),
+    ///     200,
     ///     TimeInForceType::Day,
     /// )
     /// .submitted_price(decimal!(50i32));
@@ -346,7 +385,7 @@ impl TradeContext {
             .await?)
     }
 
-    /// Withdraw order
+    /// Cancel order
     ///
     /// Reference: <https://open.longbridgeapp.com/en/docs/trade/order/withdraw>
     ///
@@ -361,11 +400,11 @@ impl TradeContext {
     /// let config = Arc::new(Config::from_env()?);
     /// let (ctx, _) = TradeContext::try_new(config).await?;
     ///
-    /// ctx.withdraw_order("709043056541253632").await?;
+    /// ctx.cancel_order("709043056541253632").await?;
     /// # Ok::<_, Box<dyn std::error::Error>>(())
     /// # });
     /// ```
-    pub async fn withdraw_order(&self, order_id: impl Into<String>) -> Result<()> {
+    pub async fn cancel_order(&self, order_id: impl Into<String>) -> Result<()> {
         #[derive(Debug, Serialize)]
         struct Request {
             order_id: String,
@@ -374,11 +413,13 @@ impl TradeContext {
         Ok(self
             .http_cli
             .request(Method::DELETE, "/v1/trade/order")
+            .response::<EmptyResponse>()
             .query_params(Request {
                 order_id: order_id.into(),
             })
             .send()
-            .await?)
+            .await
+            .map(|_| ())?)
     }
 
     /// Get account balance
@@ -522,4 +563,41 @@ impl TradeContext {
             .send()
             .await?)
     }
+
+    /// Get margin ratio
+    ///
+    /// Reference: <https://open.longbridgeapp.com/en/docs/trade/asset/margin_ratio>
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use std::sync::Arc;
+    ///
+    /// use longbridge::{trade::TradeContext, Config};
+    ///
+    /// # tokio::runtime::Runtime::new().unwrap().block_on(async {
+    /// let config = Arc::new(Config::from_env()?);
+    /// let (ctx, _) = TradeContext::try_new(config).await?;
+    ///
+    /// let resp = ctx.margin_ratio("700.HK").await?;
+    /// println!("{:?}", resp);
+    /// # Ok::<_, Box<dyn std::error::Error>>(())
+    /// # });
+    /// ```
+    pub async fn margin_ratio(&self, symbol: impl Into<String>) -> Result<MarginRatio> {
+        #[derive(Debug, Serialize)]
+        struct Request {
+            symbol: String,
+        }
+
+        Ok(self
+            .http_cli
+            .request(Method::GET, "/v1/risk/margin-ratio")
+            .query_params(Request {
+                symbol: symbol.into(),
+            })
+            .response::<MarginRatio>()
+            .send()
+            .await?)
+    }
 }
