@@ -4,7 +4,7 @@ use serde::{Deserialize, Deserializer, Serialize, Serializer};
 use strum_macros::{Display, EnumString};
 use time::{Date, OffsetDateTime};
 
-use crate::trade::serde_utils;
+use crate::{serde_utils, Market};
 
 /// Order type
 #[derive(Debug, Copy, Clone, Hash, Eq, PartialEq, EnumString, Display)]
@@ -49,6 +49,9 @@ pub enum OrderType {
     /// Trailing Market If Touched (Trailing Percent)
     #[strum(serialize = "TSMPCT")]
     TSMPCT,
+    /// Special Limit Order
+    #[strum(serialize = "SLO")]
+    SLO,
 }
 
 /// Order status
@@ -123,7 +126,8 @@ pub struct Execution {
     #[serde(with = "serde_utils::timestamp")]
     pub trade_done_at: OffsetDateTime,
     /// Executed quantity
-    pub quantity: Decimal,
+    #[serde(with = "serde_utils::int64_str")]
+    pub quantity: i64,
     /// Executed price
     pub price: Decimal,
 }
@@ -231,10 +235,11 @@ pub struct Order {
     /// Stock name
     pub stock_name: String,
     /// Submitted quantity
-    pub quantity: Decimal,
+    #[serde(with = "serde_utils::int64_str")]
+    pub quantity: i64,
     /// Executed quantity
-    #[serde(with = "serde_utils::decimal_opt_0_is_none")]
-    pub executed_quantity: Option<Decimal>,
+    #[serde(with = "serde_utils::int64_str")]
+    pub executed_quantity: i64,
     /// Submitted price
     #[serde(with = "serde_utils::decimal_opt_empty_is_none")]
     pub price: Option<Decimal>,
@@ -315,8 +320,8 @@ pub struct AccountBalance {
     /// Remaining financing amount
     pub remaining_finance_amount: Decimal,
     /// Risk control level
-    #[serde(with = "serde_utils::number_str_opt")]
-    pub risk_level: Option<i32>,
+    #[serde(with = "serde_utils::risk_level")]
+    pub risk_level: i32,
     /// Margin call
     pub margin_call: Decimal,
     /// Currency
@@ -324,6 +329,15 @@ pub struct AccountBalance {
     /// Cash details
     #[serde(default)]
     pub cash_infos: Vec<CashInfo>,
+    /// Net assets
+    #[serde(with = "serde_utils::decimal_empty_is_0")]
+    pub net_assets: Decimal,
+    /// Initial margin
+    #[serde(with = "serde_utils::decimal_empty_is_0")]
+    pub init_margin: Decimal,
+    /// Maintenance margin
+    #[serde(with = "serde_utils::decimal_empty_is_0")]
+    pub maintenance_margin: Decimal,
 }
 
 /// Balance type
@@ -333,7 +347,7 @@ pub enum BalanceType {
     /// Unknown
     #[num_enum(default)]
     Unknown = 0,
-    /// Limit Order
+    /// Cash
     Cash = 1,
     /// Stock
     Stock = 2,
@@ -364,7 +378,7 @@ pub enum CashFlowDirection {
     Unknown,
     /// Out
     Out = 1,
-    /// Stock
+    /// In
     In = 2,
 }
 
@@ -389,10 +403,10 @@ pub struct CashFlow {
     /// Cash currency
     pub currency: String,
     /// Business time
-    #[serde(with = "serde_utils::timestamp_int")]
+    #[serde(with = "serde_utils::timestamp")]
     pub business_time: OffsetDateTime,
     /// Associated Stock code information
-    #[serde(with = "serde_utils::cash_flow_symbol")]
+    #[serde(with = "serde_utils::symbol_opt")]
     pub symbol: Option<String>,
     /// Cash flow description
     pub description: String,
@@ -423,17 +437,20 @@ pub struct FundPosition {
     /// Fund ISIN code
     pub symbol: String,
     /// Current equity
+    #[serde(with = "serde_utils::decimal_empty_is_0")]
     pub current_net_asset_value: Decimal,
     /// Current equity time
-    #[serde(with = "serde_utils::timestamp_int")]
+    #[serde(with = "serde_utils::timestamp")]
     pub net_asset_value_day: OffsetDateTime,
     /// Fund name
     pub symbol_name: String,
     /// Currency
     pub currency: String,
     /// Net cost
+    #[serde(with = "serde_utils::decimal_empty_is_0")]
     pub cost_net_asset_value: Decimal,
     /// Holding units
+    #[serde(with = "serde_utils::decimal_empty_is_0")]
     pub holding_units: Decimal,
 }
 
@@ -451,7 +468,7 @@ pub struct StockPositionChannel {
     /// Account type
     pub account_channel: String,
 
-    /// Fund positions
+    /// Stock positions
     #[serde(default, rename = "stock_info")]
     pub positions: Vec<StockPosition>,
 }
@@ -464,15 +481,30 @@ pub struct StockPosition {
     /// Stock name
     pub symbol_name: String,
     /// The number of holdings
-    #[serde(rename = "quality")]
-    pub quantity: Decimal,
+    #[serde(with = "serde_utils::int64_str")]
+    pub quantity: i64,
     /// Available quantity
-    pub available_quality: Decimal,
+    #[serde(with = "serde_utils::int64_str")]
+    pub available_quantity: i64,
     /// Currency
     pub currency: String,
     /// Cost Price(According to the client's choice of average purchase or
     /// diluted cost)
+    #[serde(with = "serde_utils::decimal_empty_is_0")]
     pub cost_price: Decimal,
+    /// Market
+    pub market: Market,
+}
+
+/// Margin ratio
+#[derive(Debug, Clone, Deserialize)]
+pub struct MarginRatio {
+    /// Initial margin ratio
+    pub im_factor: Decimal,
+    /// Maintain the initial margin ratio
+    pub mm_factor: Decimal,
+    /// Forced close-out margin ratio
+    pub fm_factor: Decimal,
 }
 
 impl_serde_for_enum_string!(
@@ -515,7 +547,7 @@ mod tests {
                     "holding_units": "5.000",
                     "current_net_asset_value": "0",
                     "cost_net_asset_value": "0.00",
-                    "net_asset_value_day": 1649865600
+                    "net_asset_value_day": "1649865600"
                 }]
             }]
         }
@@ -550,17 +582,19 @@ mod tests {
                     "symbol": "700.HK",
                     "symbol_name": "腾讯控股",
                     "currency": "HK",
-                    "quality": "650",
-                    "available_quality": "-450",
-                    "cost_price": "457.53"
+                    "quantity": "650",
+                    "available_quantity": "-450",
+                    "cost_price": "457.53",
+                    "market": "HK"
                   },
                   {
                     "symbol": "9991.HK",
                     "symbol_name": "宝尊电商-SW",
                     "currency": "HK",
-                    "quality": "200",
-                    "available_quality": "0",
-                    "cost_price": "32.25"
+                    "quantity": "200",
+                    "available_quantity": "0",
+                    "cost_price": "32.25",
+                    "market": "HK"
                   }
                 ]
               }
@@ -579,24 +613,26 @@ mod tests {
         assert_eq!(position.symbol, "700.HK");
         assert_eq!(position.symbol_name, "腾讯控股");
         assert_eq!(position.currency, "HK");
-        assert_eq!(position.quantity, decimal!(650i32));
-        assert_eq!(position.available_quality, decimal!(-450i32));
+        assert_eq!(position.quantity, 650);
+        assert_eq!(position.available_quantity, -450);
         assert_eq!(position.cost_price, decimal!(457.53f32));
+        assert_eq!(position.market, Market::HK);
 
         let position = &channel.positions[0];
         assert_eq!(position.symbol, "700.HK");
         assert_eq!(position.symbol_name, "腾讯控股");
         assert_eq!(position.currency, "HK");
-        assert_eq!(position.quantity, decimal!(650i32));
-        assert_eq!(position.available_quality, decimal!(-450i32));
+        assert_eq!(position.quantity, 650);
+        assert_eq!(position.available_quantity, -450);
         assert_eq!(position.cost_price, decimal!(457.53f32));
+        assert_eq!(position.market, Market::HK);
 
         let position = &channel.positions[1];
         assert_eq!(position.symbol, "9991.HK");
         assert_eq!(position.symbol_name, "宝尊电商-SW");
         assert_eq!(position.currency, "HK");
-        assert_eq!(position.quantity, decimal!(200i32));
-        assert_eq!(position.available_quality, decimal!(0i32));
+        assert_eq!(position.quantity, 200);
+        assert_eq!(position.available_quantity, 0);
         assert_eq!(position.cost_price, decimal!(32.25f32));
     }
 
@@ -611,7 +647,7 @@ mod tests {
                 "balance": "-248.60",
                 "currency": "USD",
                 "business_type": 1,
-                "business_time": 1621507957,
+                "business_time": "1621507957",
                 "symbol": "AAPL.US",
                 "description": "AAPL"
               },
@@ -621,7 +657,7 @@ mod tests {
                 "balance": "-125.16",
                 "currency": "USD",
                 "business_type": 2,
-                "business_time": 1621504824,
+                "business_time": "1621504824",
                 "symbol": "AAPL.US",
                 "description": "AAPL"
               }
@@ -685,7 +721,10 @@ mod tests {
                     "settling_cash": "-276806.51",
                     "currency": "USD"
                   }
-                ]
+                ],
+                "net_assets": "11111.12",
+                "init_margin": "2222.23",
+                "maintenance_margin": "3333.45"
               }
             ]
           }"#;
@@ -702,9 +741,12 @@ mod tests {
         assert_eq!(balance.total_cash, "1759070010.72".parse().unwrap());
         assert_eq!(balance.max_finance_amount, "977582000".parse().unwrap());
         assert_eq!(balance.remaining_finance_amount, decimal!(0i32));
-        assert_eq!(balance.risk_level, Some(1));
+        assert_eq!(balance.risk_level, 1);
         assert_eq!(balance.margin_call, "2598051051.50".parse().unwrap());
         assert_eq!(balance.currency, "HKD");
+        assert_eq!(balance.net_assets, "11111.12".parse().unwrap());
+        assert_eq!(balance.init_margin, "2222.23".parse().unwrap());
+        assert_eq!(balance.maintenance_margin, "3333.45".parse().unwrap());
 
         assert_eq!(balance.cash_infos.len(), 2);
 
@@ -770,7 +812,7 @@ mod tests {
         let order = &resp.orders[0];
         assert_eq!(order.currency, "HKD");
         assert!(order.executed_price.is_none());
-        assert!(order.executed_quantity.is_none());
+        assert_eq!(order.executed_quantity, 0);
         assert!(order.expire_date.is_none());
         assert!(order.last_done.is_none());
         assert!(order.limit_offset.is_none());
@@ -779,7 +821,7 @@ mod tests {
         assert_eq!(order.order_type, OrderType::ELO);
         assert!(order.outside_rth.is_none());
         assert_eq!(order.price, Some("11.900".parse().unwrap()));
-        assert_eq!(order.quantity, "200".parse().unwrap());
+        assert_eq!(order.quantity, 200);
         assert_eq!(order.side, OrderSide::Buy);
         assert_eq!(order.status, OrderStatus::Rejected);
         assert_eq!(order.stock_name, "Bank of East Asia Ltd/The");
@@ -842,7 +884,7 @@ mod tests {
         let order = &resp.orders[0];
         assert_eq!(order.currency, "HKD");
         assert!(order.executed_price.is_none());
-        assert!(order.executed_quantity.is_none());
+        assert_eq!(order.executed_quantity, 0);
         assert!(order.expire_date.is_none());
         assert!(order.last_done.is_none());
         assert!(order.limit_offset.is_none());
@@ -851,7 +893,7 @@ mod tests {
         assert_eq!(order.order_type, OrderType::ELO);
         assert!(order.outside_rth.is_none());
         assert_eq!(order.price, Some("11.900".parse().unwrap()));
-        assert_eq!(order.quantity, "200".parse().unwrap());
+        assert_eq!(order.quantity, 200);
         assert_eq!(order.side, OrderSide::Buy);
         assert_eq!(order.status, OrderStatus::Rejected);
         assert_eq!(order.stock_name, "Bank of East Asia Ltd/The");
@@ -896,7 +938,7 @@ mod tests {
         let execution = &resp.trades[0];
         assert_eq!(execution.order_id, "693664675163312128");
         assert_eq!(execution.price, "388".parse().unwrap());
-        assert_eq!(execution.quantity, "100".parse().unwrap());
+        assert_eq!(execution.quantity, 100);
         assert_eq!(execution.symbol, "700.HK");
         assert_eq!(execution.trade_done_at, datetime!(2022-03-30 11:35:51 +8));
         assert_eq!(execution.trade_id, "693664675163312128-1648611351433741210");
