@@ -16,17 +16,8 @@ pub(crate) struct Subscription {
     symbol: String,
     #[py(sub_types)]
     sub_types: Vec<SubType>,
-}
-
-/// Derivative type
-#[pyclass]
-#[derive(PyEnum, Debug, Copy, Clone, Hash, Eq, PartialEq)]
-#[py(remote = "longbridge::quote::DerivativeType")]
-pub(crate) enum DerivativeType {
-    /// US stock options
-    Option,
-    /// HK warrants
-    Warrant,
+    #[py(array)]
+    candlesticks: Vec<Period>,
 }
 
 #[pyclass]
@@ -189,8 +180,11 @@ pub(crate) enum WarrantType {
 #[pyclass]
 #[allow(non_camel_case_types)]
 #[derive(Debug, PyEnum, Copy, Clone, Hash, Eq, PartialEq)]
-#[py(remote = "longbridge::quote::Period", from = false)]
+#[py(remote = "longbridge::quote::Period")]
 pub(crate) enum Period {
+    /// Unknown
+    #[py(remote = "UnknownPeriod")]
+    Unknown,
     /// One Minute
     #[py(remote = "OneMinute")]
     Min_1,
@@ -206,7 +200,7 @@ pub(crate) enum Period {
     /// Sixty Minutes
     #[py(remote = "SixtyMinute")]
     Min_60,
-    /// One Days
+    /// One Day
     Day,
     /// One Week
     Week,
@@ -227,6 +221,89 @@ pub(crate) enum AdjustType {
     ForwardAdjust,
 }
 
+/// Derivative type
+#[pyclass]
+#[derive(Debug, Copy, Clone, Hash, Eq, PartialEq)]
+pub(crate) enum DerivativeType {
+    /// US stock options
+    Option,
+    /// HK warrants
+    Warrant,
+}
+
+struct DerivativeTypes(Vec<DerivativeType>);
+
+impl From<longbridge::quote::DerivativeType> for DerivativeTypes {
+    fn from(ty: longbridge::quote::DerivativeType) -> Self {
+        let mut res = Vec::new();
+        if ty.contains(longbridge::quote::DerivativeType::OPTION) {
+            res.push(DerivativeType::Option);
+        }
+        if ty.contains(longbridge::quote::DerivativeType::WARRANT) {
+            res.push(DerivativeType::Warrant);
+        }
+        DerivativeTypes(res)
+    }
+}
+
+/// Security board
+#[pyclass]
+#[derive(Debug, PyEnum, Copy, Clone, Hash, Eq, PartialEq)]
+#[py(remote = "longbridge::quote::SecurityBoard")]
+#[allow(clippy::upper_case_acronyms)]
+pub enum SecurityBoard {
+    /// Unknown
+    Unknown,
+    /// US Main Board
+    USMain,
+    /// US Pink Board
+    USPink,
+    /// Dow Jones Industrial Average
+    USDJI,
+    /// Nasdsaq Index
+    USNSDQ,
+    /// US Industry Board
+    USSector,
+    /// US Option
+    USOption,
+    /// US Sepecial Option
+    USOptionS,
+    /// Hong Kong Equity Securities
+    HKEquity,
+    /// HK PreIPO Security
+    HKPreIPO,
+    /// HK Warrant
+    HKWarrant,
+    /// Hang Seng Index
+    HKHS,
+    /// HK Industry Board
+    HKSector,
+    /// SH Main Board(Connect)
+    SHMainConnect,
+    /// SH Main Board(Non Connect)
+    SHMainNonConnect,
+    /// SH Science and Technology Innovation Board
+    SHSTAR,
+    /// CN Index
+    CNIX,
+    /// CN Industry Board
+    CNSector,
+    /// SZ Main Board(Connect)
+    SZMainConnect,
+    /// SZ Main Board(Non Connect)
+    SZMainNonConnect,
+    /// SZ Gem Board(Connect)
+    SZGEMConnect,
+    /// SZ Gem Board(Non Connect)
+    SZGEMNonConnect,
+    /// SG Main Board
+    SGMain,
+    /// Singapore Straits Index
+    STI,
+    /// SG Industry Board
+    SGSector,
+}
+
 /// The basic information of securities
 #[pyclass]
 #[derive(Debug, PyObject)]
@@ -261,8 +338,10 @@ pub(crate) struct SecurityStaticInfo {
     /// Dividend yield
     dividend_yield: PyDecimal,
     /// Types of supported derivatives
-    #[py(array)]
+    #[py(derivative_types)]
     stock_derivatives: Vec<DerivativeType>,
+    /// Board
+    board: SecurityBoard,
 }
 
 /// Quote of US pre/post market
@@ -400,7 +479,7 @@ pub(crate) struct WarrantQuote {
     /// Outstanding ratio
     outstanding_ratio: PyDecimal,
     /// Outstanding quantity
-    outstanding_qty: i64,
+    outstanding_quantity: i64,
     /// Conversion ratio
     conversion_ratio: PyDecimal,
     /// Warrant type
@@ -522,7 +601,7 @@ pub(crate) struct IntradayLine {
 
 /// Candlestick
 #[pyclass]
-#[derive(Debug, PyObject)]
+#[derive(Debug, PyObject, Clone)]
 #[py(remote = "longbridge::quote::Candlestick")]
 pub(crate) struct Candlestick {
     /// Close price
@@ -591,9 +670,9 @@ pub(crate) struct TradingSessionInfo {
 pub(crate) struct MarketTradingSession {
     /// Market
     market: Market,
-    /// Trading session
+    /// Trading sessions
     #[py(array)]
-    trade_session: Vec<TradingSessionInfo>,
+    trade_sessions: Vec<TradingSessionInfo>,
 }
 
 /// Real-time quote
@@ -677,17 +756,28 @@ pub(crate) struct PushBrokers {
 #[pyclass]
 #[derive(Debug, PyObject)]
 #[py(remote = "longbridge::quote::PushTrades")]
-pub struct PushTrades {
+pub(crate) struct PushTrades {
     /// Trades data
     #[py(array)]
     trades: Vec<Trade>,
 }
 
+/// Push candlestick updated event
+#[pyclass]
+#[derive(Debug, PyObject)]
+#[py(remote = "longbridge::quote::PushCandlestick")]
+pub struct PushCandlestick {
+    /// Period type
+    period: Period,
+    /// Candlestick
+    candlestick: Candlestick,
+}
+
 /// Market trading days
 #[pyclass]
 #[derive(Debug, PyObject)]
 #[py(remote = "longbridge::quote::MarketTradingDays")]
-pub struct MarketTradingDays {
+pub(crate) struct MarketTradingDays {
     /// Trading days
     #[py(array)]
     trading_days: Vec<PyDateWrapper>,
@@ -695,3 +785,72 @@ pub struct MarketTradingDays {
     #[py(array)]
     half_trading_days: Vec<PyDateWrapper>,
 }
+
+/// Capital flow line
+#[pyclass]
+#[derive(Debug, PyObject)]
+#[py(remote = "longbridge::quote::CapitalFlowLine")]
+pub(crate) struct CapitalFlowLine {
+    /// Inflow capital data
+    inflow: PyDecimal,
+    /// Time
+    timestamp: PyOffsetDateTimeWrapper,
+}
+
+/// Capital distribution
+#[pyclass]
+#[derive(Debug, PyObject, Clone)]
+#[py(remote = "longbridge::quote::CapitalDistribution")]
+pub(crate) struct CapitalDistribution {
+    /// Large order
+    large: PyDecimal,
+    /// Medium order
+    medium: PyDecimal,
+    /// Small order
+    small: PyDecimal,
+}
+
+/// Capital distribution response
+#[pyclass]
+#[derive(Debug, PyObject, Clone)]
+#[py(remote = "longbridge::quote::CapitalDistributionResponse")]
+pub(crate) struct CapitalDistributionResponse {
+    /// Time
+    timestamp: PyOffsetDateTimeWrapper,
+    /// Inflow capital data
+    capital_in: CapitalDistribution,
+    /// Outflow capital data
+    capital_out: CapitalDistribution,
+}
+
+/// Watch list group
+#[pyclass]
+#[derive(Debug, PyObject, Clone)]
+#[py(remote = "longbridge::quote::WatchListGroup")]
+pub(crate) struct WatchListGroup {
+    /// Group id
+    pub id: i64,
+    /// Group name
+    pub name: String,
+    /// Securities
+    #[py(array)]
+    securities: Vec<WatchListSecurity>,
+}
+
+/// Watch list security
+#[pyclass]
+#[derive(Debug, PyObject, Clone)]
+#[py(remote = "longbridge::quote::WatchListSecurity")]
+pub(crate) struct WatchListSecurity {
+    /// Security symbol
+    symbol: String,
+    /// Market
+    market: Market,
+    /// Security name
+    name: String,
+    /// Watched price
+    #[py(opt)]
+    watched_price: Option<PyDecimal>,
+    /// Watched time
+    watched_at: PyOffsetDateTimeWrapper,
+}
